@@ -28,6 +28,7 @@
 #include "dbusauthobserver.h"
 #include "dbusconnection.h"
 #include "dbuserror.h"
+#include "dbuserrorutils.h"
 #include "dbusintrospection.h"
 #include "dbusmessage.h"
 #include "dbusmethodinvocation.h"
@@ -107,16 +108,12 @@ extern "C"
 GType g_app_launch_context_get_type(void);
 GType g_application_get_type(void);
 GType g_application_command_line_get_type(void);
+GType g_dbus_auth_observer_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
 GType g_cancellable_get_type(void);
-GType g_credentials_get_type(void);
-GType g_dbus_auth_observer_get_type(void);
 GType g_dbus_connection_get_type(void);
-GType g_dbus_message_get_type(void);
-GType g_dbus_method_invocation_get_type(void);
-GType g_dbus_proxy_get_type(void);
-GType g_dbus_server_get_type(void);
+GType g_credentials_get_type(void);
 GType g_data_input_stream_get_type(void);
 GType g_data_output_stream_get_type(void);
 #ifndef G_OS_WIN32
@@ -140,12 +137,16 @@ GType g_inet_socket_address_get_type(void);
 GType g_input_stream_get_type(void);
 GType g_memory_input_stream_get_type(void);
 GType g_memory_output_stream_get_type(void);
+GType g_dbus_message_get_type(void);
+GType g_dbus_method_invocation_get_type(void);
 GType g_mount_operation_get_type(void);
 GType g_network_address_get_type(void);
 GType g_network_service_get_type(void);
 GType g_output_stream_get_type(void);
+GType g_dbus_proxy_get_type(void);
 GType g_proxy_address_get_type(void);
 GType g_resolver_get_type(void);
+GType g_dbus_server_get_type(void);
 GType g_settings_get_type(void);
 GType g_socket_get_type(void);
 GType g_socket_address_get_type(void);
@@ -194,16 +195,12 @@ GQuark g_resolver_error_quark(void);
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class ApplicationCommandLine_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio { namespace DBus {  class AuthObserver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Cancellable_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio { namespace DBus {  class Connection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gio {  class Credentials_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class DBusAuthObserver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class DBusConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class DBusMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class DBusMethodInvocation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class DBusProxy_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
-namespace Gio {  class DBusServer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
@@ -227,12 +224,16 @@ namespace Gio {  class InetSocketAddress_Class { public: static Glib::ObjectBase
 namespace Gio {  class InputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MemoryInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class MemoryOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio { namespace DBus {  class Message_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
+namespace Gio { namespace DBus {  class MethodInvocation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gio {  class MountOperation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class NetworkAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class NetworkService_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class OutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Proxy_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class ProxyAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Resolver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio { namespace DBus {  class Server_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 namespace Gio {  class Settings_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Socket_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -273,24 +274,20 @@ namespace Gio {
 void wrap_init()
 {
   // Register Error domains:
-  Glib::Error::register_domain(g_dbus_error_quark(), &Gio::DBusError::throw_func);
-  Glib::Error::register_domain(g_io_error_quark(), &Gio::Error::throw_func);
-  Glib::Error::register_domain(g_resolver_error_quark(), &Gio::ResolverError::throw_func);
+  Glib::Error::register_domain(g_dbus_error_quark(), &::Gio::DBus::Error::throw_func);
+  Glib::Error::register_domain(g_io_error_quark(), &::Gio::Error::throw_func);
+  Glib::Error::register_domain(g_resolver_error_quark(), &::Gio::ResolverError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
   Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
   Glib::wrap_register(g_application_command_line_get_type(), &Gio::ApplicationCommandLine_Class::wrap_new);
+  Glib::wrap_register(g_dbus_auth_observer_get_type(), &Gio::DBus::AuthObserver_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
   Glib::wrap_register(g_cancellable_get_type(), &Gio::Cancellable_Class::wrap_new);
+  Glib::wrap_register(g_dbus_connection_get_type(), &Gio::DBus::Connection_Class::wrap_new);
   Glib::wrap_register(g_credentials_get_type(), &Gio::Credentials_Class::wrap_new);
-  Glib::wrap_register(g_dbus_auth_observer_get_type(), &Gio::DBusAuthObserver_Class::wrap_new);
-  Glib::wrap_register(g_dbus_connection_get_type(), &Gio::DBusConnection_Class::wrap_new);
-  Glib::wrap_register(g_dbus_message_get_type(), &Gio::DBusMessage_Class::wrap_new);
-  Glib::wrap_register(g_dbus_method_invocation_get_type(), &Gio::DBusMethodInvocation_Class::wrap_new);
-  Glib::wrap_register(g_dbus_proxy_get_type(), &Gio::DBusProxy_Class::wrap_new);
-  Glib::wrap_register(g_dbus_server_get_type(), &Gio::DBusServer_Class::wrap_new);
   Glib::wrap_register(g_data_input_stream_get_type(), &Gio::DataInputStream_Class::wrap_new);
   Glib::wrap_register(g_data_output_stream_get_type(), &Gio::DataOutputStream_Class::wrap_new);
 #ifndef G_OS_WIN32
@@ -314,12 +311,16 @@ void wrap_init()
   Glib::wrap_register(g_input_stream_get_type(), &Gio::InputStream_Class::wrap_new);
   Glib::wrap_register(g_memory_input_stream_get_type(), &Gio::MemoryInputStream_Class::wrap_new);
   Glib::wrap_register(g_memory_output_stream_get_type(), &Gio::MemoryOutputStream_Class::wrap_new);
+  Glib::wrap_register(g_dbus_message_get_type(), &Gio::DBus::Message_Class::wrap_new);
+  Glib::wrap_register(g_dbus_method_invocation_get_type(), &Gio::DBus::MethodInvocation_Class::wrap_new);
   Glib::wrap_register(g_mount_operation_get_type(), &Gio::MountOperation_Class::wrap_new);
   Glib::wrap_register(g_network_address_get_type(), &Gio::NetworkAddress_Class::wrap_new);
   Glib::wrap_register(g_network_service_get_type(), &Gio::NetworkService_Class::wrap_new);
   Glib::wrap_register(g_output_stream_get_type(), &Gio::OutputStream_Class::wrap_new);
+  Glib::wrap_register(g_dbus_proxy_get_type(), &Gio::Proxy_Class::wrap_new);
   Glib::wrap_register(g_proxy_address_get_type(), &Gio::ProxyAddress_Class::wrap_new);
   Glib::wrap_register(g_resolver_get_type(), &Gio::Resolver_Class::wrap_new);
+  Glib::wrap_register(g_dbus_server_get_type(), &Gio::DBus::Server_Class::wrap_new);
   Glib::wrap_register(g_settings_get_type(), &Gio::Settings_Class::wrap_new);
   Glib::wrap_register(g_socket_get_type(), &Gio::Socket_Class::wrap_new);
   Glib::wrap_register(g_socket_address_get_type(), &Gio::SocketAddress_Class::wrap_new);
@@ -359,16 +360,12 @@ void wrap_init()
   Gio::AppLaunchContext::get_type();
   Gio::Application::get_type();
   Gio::ApplicationCommandLine::get_type();
+  Gio::DBus::AuthObserver::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
   Gio::Cancellable::get_type();
+  Gio::DBus::Connection::get_type();
   Gio::Credentials::get_type();
-  Gio::DBusAuthObserver::get_type();
-  Gio::DBusConnection::get_type();
-  Gio::DBusMessage::get_type();
-  Gio::DBusMethodInvocation::get_type();
-  Gio::DBusProxy::get_type();
-  Gio::DBusServer::get_type();
   Gio::DataInputStream::get_type();
   Gio::DataOutputStream::get_type();
 #ifndef G_OS_WIN32
@@ -392,12 +389,16 @@ void wrap_init()
   Gio::InputStream::get_type();
   Gio::MemoryInputStream::get_type();
   Gio::MemoryOutputStream::get_type();
+  Gio::DBus::Message::get_type();
+  Gio::DBus::MethodInvocation::get_type();
   Gio::MountOperation::get_type();
   Gio::NetworkAddress::get_type();
   Gio::NetworkService::get_type();
   Gio::OutputStream::get_type();
+  Gio::Proxy::get_type();
   Gio::ProxyAddress::get_type();
   Gio::Resolver::get_type();
+  Gio::DBus::Server::get_type();
   Gio::Settings::get_type();
   Gio::Socket::get_type();
   Gio::SocketAddress::get_type();
